==> aws-cdk-lib-2.0.0-rc.20-sources.jar: software/amazon/awscdk/services/cloudwatch/Alarm.java <==
package software.amazon.awscdk.services.cloudwatch;

/**
 * (experimental) An alarm on a CloudWatch metric.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-09-01T10:25:59.955Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_cloudwatch.Alarm")
public class Alarm extends software.amazon.awscdk.services.cloudwatch.AlarmBase {

    protected Alarm(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Alarm(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Alarm(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.AlarmProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * (experimental) Import an existing CloudWatch alarm provided an ARN.
     * <p>
     * @param scope The parent creating construct (usually `this`). This parameter is required.
     * @param id The construct's name. This parameter is required.
     * @param alarmArn Alarm ARN (i.e. arn:aws:cloudwatch:<region>:<account-id>:alarm:Foo). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarm fromAlarmArn(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String alarmArn) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudwatch.Alarm.class, "fromAlarmArn", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.IAlarm.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(alarmArn, "alarmArn is required") });
    }

    /**
     * (experimental) Trigger this action if the alarm fires.
     * <p>
     * Typically the ARN of an SNS topic or ARN of an AutoScaling policy.
     * <p>
     * @param actions This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public void addAlarmAction(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarmAction... actions) {
        software.amazon.jsii.Kernel.call(this, "addAlarmAction", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(actions).toArray(Object[]::new));
    }

    /**
     * (experimental) Turn this alarm into a horizontal annotation.
     * <p>
     * This is useful if you want to represent an Alarm in a non-AlarmWidget.
     * An <code>AlarmWidget</code> can directly show an alarm, but it can only show a
     * single alarm and no other metrics. Instead, you can convert the alarm to
     * a HorizontalAnnotation and add it as an annotation to another graph.
     * <p>
     * This might be useful if:
     * <p>
     * <ul>
     * <li>You want to show multiple alarms inside a single graph, for example if
     * you have both a "small margin/long period" alarm as well as a
     * "large margin/short period" alarm.</li>
     * <li>You want to show an Alarm line in a graph with multiple metrics in it.</li>
     * </ul>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.HorizontalAnnotation toAnnotation() {
        return software.amazon.jsii.Kernel.call(this, "toAnnotation", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.HorizontalAnnotation.class));
    }

    /**
     * (experimental) ARN of this alarm.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getAlarmArn() {
        return software.amazon.jsii.Kernel.get(this, "alarmArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) Name of this alarm.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getAlarmName() {
        return software.amazon.jsii.Kernel.get(this, "alarmName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) The metric object this alarm was based on.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IMetric getMetric() {
        return software.amazon.jsii.Kernel.get(this, "metric", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.IMetric.class));
    }

    /**
     * (experimental) A fluent builder for {@link software.amazon.awscdk.services.cloudwatch.Alarm}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.cloudwatch.Alarm> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.cloudwatch.AlarmProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.cloudwatch.AlarmProps.Builder();
        }

        /**
         * (experimental) The number of periods over which data is compared to the specified threshold.
         * <p>
         * @return {@code this}
         * @param evaluationPeriods The number of periods over which data is compared to the specified threshold. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder evaluationPeriods(final java.lang.Number evaluationPeriods) {
            this.props.evaluationPeriods(evaluationPeriods);
            return this;
        }

        /**
         * (experimental) The value against which the specified statistic is compared.
         * <p>
         * @return {@code this}
         * @param threshold The value against which the specified statistic is compared. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder threshold(final java.lang.Number threshold) {
            this.props.threshold(threshold);
            return this;
        }

        /**
         * (experimental) Whether the actions for this alarm are enabled.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param actionsEnabled Whether the actions for this alarm are enabled. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder actionsEnabled(final java.lang.Boolean actionsEnabled) {
            this.props.actionsEnabled(actionsEnabled);
            return this;
        }

        /**
         * (experimental) Description for the alarm.
         * <p>
         * Default: No description
         * <p>
         * @return {@code this}
         * @param alarmDescription Description for the alarm. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder alarmDescription(final java.lang.String alarmDescription) {
            this.props.alarmDescription(alarmDescription);
            return this;
        }

        /**
         * (experimental) Name of the alarm.
         * <p>
         * Default: Automatically generated name
         * <p>
         * @return {@code this}
         * @param alarmName Name of the alarm. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder alarmName(final java.lang.String alarmName) {
            this.props.alarmName(alarmName);
            return this;
        }

        /**
         * (experimental) Comparison to use to check if metric is breaching.
         * <p>
         * Default: GreaterThanOrEqualToThreshold
         * <p>
         * @return {@code this}
         * @param comparisonOperator Comparison to use to check if metric is breaching. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder comparisonOperator(final software.amazon.awscdk.services.cloudwatch.ComparisonOperator comparisonOperator) {
            this.props.comparisonOperator(comparisonOperator);
            return this;
        }

        /**
         * (experimental) The number of datapoints that must be breaching to trigger the alarm.
         * <p>
         * This is used only if you are setting an "M
         * out of N" alarm. In that case, this value is the M. For more information, see Evaluating an Alarm in the Amazon
         * CloudWatch User Guide.
         * <p>
         * Default: ``evaluationPeriods``
         * <p>
         * @return {@code this}
         * @see https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/AlarmThatSendsEmail.html#alarm-evaluation
         * @param datapointsToAlarm The number of datapoints that must be breaching to trigger the alarm. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder datapointsToAlarm(final java.lang.Number datapointsToAlarm) {
            this.props.datapointsToAlarm(datapointsToAlarm);
            return this;
        }

        /**
         * (experimental) Specifies whether to evaluate the data and potentially change the alarm state if there are too few data points to be statistically significant.
         * <p>
         * Used only for alarms that are based on percentiles.
         * <p>
         * Default: - Not configured.
         * <p>
         * @return {@code this}
         * @param evaluateLowSampleCountPercentile Specifies whether to evaluate the data and potentially change the alarm state if there are too few data points to be statistically significant. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder evaluateLowSampleCountPercentile(final java.lang.String evaluateLowSampleCountPercentile) {
            this.props.evaluateLowSampleCountPercentile(evaluateLowSampleCountPercentile);
            return this;
        }

        /**
         * (experimental) Sets how this alarm is to handle missing data points.
         * <p>
         * Default: TreatMissingData.Missing
         * <p>
         * @return {@code this}
         * @param treatMissingData Sets how this alarm is to handle missing data points. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder treatMissingData(final software.amazon.awscdk.services.cloudwatch.TreatMissingData treatMissingData) {
            this.props.treatMissingData(treatMissingData);
            return this;
        }

        /**
         * (experimental) The metric to add the alarm on.
         * <p>
         * Metric objects can be obtained from most resources, or you can construct
         * custom Metric objects by instantiating one.
         * <p>
         * @return {@code this}
         * @param metric The metric to add the alarm on. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder metric(final software.amazon.awscdk.services.cloudwatch.IMetric metric) {
            this.props.metric(metric);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.cloudwatch.Alarm}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.cloudwatch.Alarm build() {
            return new software.amazon.awscdk.services.cloudwatch.Alarm(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/cloudwatch/Alarm.java <==
package software.amazon.awscdk.services.cloudwatch;

/**
 * An alarm on a CloudWatch metric.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * import software.amazon.awscdk.services.cloudwatch.*;
 * DeliveryStream deliveryStream;
 * // Alarm that triggers when the per-second average of incoming bytes exceeds 90% of the current service limit
 * MathExpression incomingBytesPercentOfLimit = MathExpression.Builder.create()
 *         .expression("incomingBytes / 300 / bytePerSecLimit")
 *         .usingMetrics(Map.of(
 *                 "incomingBytes", deliveryStream.metricIncomingBytes(MetricOptions.builder().statistic(Statistic.SUM).build()),
 *                 "bytePerSecLimit", deliveryStream.metric("BytesPerSecondLimit")))
 *         .build();
 * Alarm.Builder.create(this, "Alarm")
 *         .metric(incomingBytesPercentOfLimit)
 *         .threshold(0.9)
 *         .evaluationPeriods(3)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:08.109Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_cloudwatch.Alarm")
public class Alarm extends software.amazon.awscdk.services.cloudwatch.AlarmBase {

    protected Alarm(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Alarm(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public Alarm(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.AlarmProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Import an existing CloudWatch alarm provided an ARN.
     * <p>
     * @param scope The parent creating construct (usually `this`). This parameter is required.
     * @param id The construct's name. This parameter is required.
     * @param alarmArn Alarm ARN (i.e. arn:aws:cloudwatch:<region>:<account-id>:alarm:Foo). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarm fromAlarmArn(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String alarmArn) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudwatch.Alarm.class, "fromAlarmArn", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.IAlarm.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(alarmArn, "alarmArn is required") });
    }

    /**
     * Trigger this action if the alarm fires.
     * <p>
     * Typically the ARN of an SNS topic or ARN of an AutoScaling policy.
     * <p>
     * @param actions This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public void addAlarmAction(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarmAction... actions) {
        software.amazon.jsii.Kernel.call(this, "addAlarmAction", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(actions).toArray(Object[]::new));
    }

    /**
     * Turn this alarm into a horizontal annotation.
     * <p>
     * This is useful if you want to represent an Alarm in a non-AlarmWidget.
     * An <code>AlarmWidget</code> can directly show an alarm, but it can only show a
     * single alarm and no other metrics. Instead, you can convert the alarm to
     * a HorizontalAnnotation and add it as an annotation to another graph.
     * <p>
     * This might be useful if:
     * <p>
     * <ul>
     * <li>You want to show multiple alarms inside a single graph, for example if
     * you have both a "small margin/long period" alarm as well as a
     * "large margin/short period" alarm.</li>
     * <li>You want to show an Alarm line in a graph with multiple metrics in it.</li>
     * </ul>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.HorizontalAnnotation toAnnotation() {
        return software.amazon.jsii.Kernel.call(this, "toAnnotation", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.HorizontalAnnotation.class));
    }

    /**
     * ARN of this alarm.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getAlarmArn() {
        return software.amazon.jsii.Kernel.get(this, "alarmArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * Name of this alarm.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getAlarmName() {
        return software.amazon.jsii.Kernel.get(this, "alarmName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * The metric object this alarm was based on.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IMetric getMetric() {
        return software.amazon.jsii.Kernel.get(this, "metric", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.IMetric.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.cloudwatch.Alarm}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.cloudwatch.Alarm> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.cloudwatch.AlarmProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.cloudwatch.AlarmProps.Builder();
        }

        /**
         * The number of periods over which data is compared to the specified threshold.
         * <p>
         * @return {@code this}
         * @param evaluationPeriods The number of periods over which data is compared to the specified threshold. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder evaluationPeriods(final java.lang.Number evaluationPeriods) {
            this.props.evaluationPeriods(evaluationPeriods);
            return this;
        }

        /**
         * The value against which the specified statistic is compared.
         * <p>
         * @return {@code this}
         * @param threshold The value against which the specified statistic is compared. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder threshold(final java.lang.Number threshold) {
            this.props.threshold(threshold);
            return this;
        }

        /**
         * Whether the actions for this alarm are enabled.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param actionsEnabled Whether the actions for this alarm are enabled. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder actionsEnabled(final java.lang.Boolean actionsEnabled) {
            this.props.actionsEnabled(actionsEnabled);
            return this;
        }

        /**
         * Description for the alarm.
         * <p>
         * Default: No description
         * <p>
         * @return {@code this}
         * @param alarmDescription Description for the alarm. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder alarmDescription(final java.lang.String alarmDescription) {
            this.props.alarmDescription(alarmDescription);
            return this;
        }

        /**
         * Name of the alarm.
         * <p>
         * Default: Automatically generated name
         * <p>
         * @return {@code this}
         * @param alarmName Name of the alarm. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder alarmName(final java.lang.String alarmName) {
            this.props.alarmName(alarmName);
            return this;
        }

        /**
         * Comparison to use to check if metric is breaching.
         * <p>
         * Default: GreaterThanOrEqualToThreshold
         * <p>
         * @return {@code this}
         * @param comparisonOperator Comparison to use to check if metric is breaching. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder comparisonOperator(final software.amazon.awscdk.services.cloudwatch.ComparisonOperator comparisonOperator) {
            this.props.comparisonOperator(comparisonOperator);
            return this;
        }

        /**
         * The number of datapoints that must be breaching to trigger the alarm.
         * <p>
         * This is used only if you are setting an "M
         * out of N" alarm. In that case, this value is the M. For more information, see Evaluating an Alarm in the Amazon
         * CloudWatch User Guide.
         * <p>
         * Default: ``evaluationPeriods``
         * <p>
         * @return {@code this}
         * @see https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/AlarmThatSendsEmail.html#alarm-evaluation
         * @param datapointsToAlarm The number of datapoints that must be breaching to trigger the alarm. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder datapointsToAlarm(final java.lang.Number datapointsToAlarm) {
            this.props.datapointsToAlarm(datapointsToAlarm);
            return this;
        }

        /**
         * Specifies whether to evaluate the data and potentially change the alarm state if there are too few data points to be statistically significant.
         * <p>
         * Used only for alarms that are based on percentiles.
         * <p>
         * Default: - Not configured.
         * <p>
         * @return {@code this}
         * @param evaluateLowSampleCountPercentile Specifies whether to evaluate the data and potentially change the alarm state if there are too few data points to be statistically significant. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder evaluateLowSampleCountPercentile(final java.lang.String evaluateLowSampleCountPercentile) {
            this.props.evaluateLowSampleCountPercentile(evaluateLowSampleCountPercentile);
            return this;
        }

        /**
         * Sets how this alarm is to handle missing data points.
         * <p>
         * Default: TreatMissingData.Missing
         * <p>
         * @return {@code this}
         * @param treatMissingData Sets how this alarm is to handle missing data points. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder treatMissingData(final software.amazon.awscdk.services.cloudwatch.TreatMissingData treatMissingData) {
            this.props.treatMissingData(treatMissingData);
            return this;
        }

        /**
         * The metric to add the alarm on.
         * <p>
         * Metric objects can be obtained from most resources, or you can construct
         * custom Metric objects by instantiating one.
         * <p>
         * @return {@code this}
         * @param metric The metric to add the alarm on. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder metric(final software.amazon.awscdk.services.cloudwatch.IMetric metric) {
            this.props.metric(metric);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.cloudwatch.Alarm}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.cloudwatch.Alarm build() {
            return new software.amazon.awscdk.services.cloudwatch.Alarm(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
